@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: UTF8 -*-
 
 # Specto , Unobtrusive event notifier
@@ -36,7 +35,7 @@ from datetime import datetime
 import spectlib.util as util
 from spectlib.watch import Watch_io
 from spectlib.logger import Logger
-from spectlib.specto_gconf import GConfClient
+from spectlib.specto_gconf import Specto_gconf
 from spectlib.i18n import _
 from spectlib.import_export import Import_watch
 from spectlib import networkmanager as conmgr
@@ -48,11 +47,13 @@ import time
 import thread
 
 #create a gconf object
-debug_gconf_client = GConfClient("/apps/specto/preferences")
+specto_gconf = Specto_gconf("/apps/specto")
 
-if debug_gconf_client.get_entry("/debug_mode", "boolean")==True:
+if specto_gconf.get_entry("debug_mode")==True:
     DEBUG = True
-elif debug_gconf_client.get_entry("/debug_mode", "boolean")==False:
+elif specto_gconf.get_entry("debug_mode")==False:
+    DEBUG = False
+else:
     DEBUG = False
 
 try:
@@ -89,31 +90,31 @@ class Specto:
         self.check_instance() #see if specto is already running
         self.util = util
         self.PATH = self.util.get_path()
-        self.GConfClient = GConfClient
-        self.conf_ui = self.GConfClient("/apps/specto/ui")
-        self.conf_pref = self.GConfClient("/apps/specto/preferences")
+        self.specto_gconf = specto_gconf
+        self.check_default_settings()#if this is the first run of specto, set the default values for gconf. Whenever you add some gconf preference for specto, this function will also need to be updated.
         self.GTK = GTK
         if GTK:
             self.tray = Tray(self)
+            self.icon_theme = gtk.icon_theme_get_default()
         self.watch_db = {}
         self.watch_io = Watch_io()
         watch_value_db = self.watch_io.read_options() 
         self.preferences_initialized = False
         self.notifier_initialized = False        
         #listen for gconf keys
-        self.conf_pref.notify_entry("/debug_mode", self.key_changed, "debug")
+        self.specto_gconf.notify_entry("debug_mode", self.key_changed, "debug")
 
         self.connection_manager = conmgr.get_net_listener()
 
         if GTK:
-            if self.conf_pref.get_entry("/always_show_icon", "boolean") == False:
+            if self.specto_gconf.get_entry("always_show_icon") == False:
                 #if the user has not requested the tray icon to be shown at all times, it's impossible that the notifier is hidden on startup, so we must show it.
                 self.notifier_keep_hidden = False
                 self.toggle_notifier()
-            elif self.conf_ui.get_entry("/notifier_state", "boolean")==True:
+            elif self.specto_gconf.get_entry("show_notifier")==True:
                 self.notifier_keep_hidden = False
                 self.toggle_notifier()
-            elif self.conf_ui.get_entry("/notifier_state", "boolean")==False:
+            elif self.specto_gconf.get_entry("show_notifier")==False:
                 self.notifier_keep_hidden = True
                 self.toggle_notifier()
                 self.notifier_keep_hidden = False
@@ -132,11 +133,33 @@ class Specto:
     def key_changed(self, *args):
         """ Listen for gconf keys. """
         label = args[3]
-        conf_pref = self.GConfClient("/apps/specto/preferences")
         
         if label == "debug":
-            self.DEBUG = conf_pref.get_entry("/debug_mode", "boolean")
-            
+            self.DEBUG = self.specto_gconf.get_entry("debug_mode")
+
+    def check_default_settings(self):
+        """ This is used to set the default settings properly the first time Specto is run, without using gconf schemas """
+        self.default_settings=(
+            ["always_show_icon", False], #having it True would be against the HIG!
+            ["debug_mode", False],
+            ["follow_website_redirects", True],
+            ["pop_toast_duration", 5],
+            ["pop_toast", True],
+            ["show_deactivated_watches", True],
+            ["show_in_windowlist", True],
+            ["show_notifier", True],
+            ["show_toolbar", True],
+            ["sort_function", "name"],
+            ["sort_order", "asc"],
+            ["update_sound", "/usr/share/sounds/ekiga/voicemail.wav"],
+            ["use_update_sound", False],
+            ["window_notifier_height", 500],
+            ["window_notifier_width", 500]
+            )
+        for default_setting in self.default_settings:
+            if self.specto_gconf.get_entry(default_setting[0]) == None: #the key has no user-defined value or does not exist
+                self.specto_gconf.set_entry(default_setting[0], default_setting[1])
+
     def check_instance(self):
         """ Check if specto is already running. """
         pidfile = os.environ['HOME'] + "/.specto/" + "specto.pid"
@@ -181,9 +204,9 @@ class Specto:
                 while gtk.events_pending():
                     gtk.main_iteration_do(False)
                     
-        if self.conf_ui.get_entry("/hide_deactivated_watches", "boolean") == True:
-            self.notifier.wTree.get_widget("display_all_watches").set_active(False)
-            self.notifier.toggle_hide_deactivated_watches()
+        if self.specto_gconf.get_entry("show_deactivated_watches")== True:
+            self.notifier.wTree.get_widget("display_all_watches").set_active(True)
+        self.notifier.toggle_show_deactivated_watches(startup=True)#True makes startup=True, only used on the first startup to avoid duplicate watches.
         
         #start the active watches
         if self.notifier_initialized:            
@@ -216,7 +239,12 @@ class Specto:
         elif values['type'] == 3: #add a process watch
             from spectlib.watch_process import Process_watch
             self.watch_db[id] = Process_watch(values['refresh'], values['process'], self, id, values['name'])
-            
+ 
+        elif values['type'] == 4: #add a port watch
+            from spectlib.watch_port import Port_watch
+            self.watch_db[id] = Port_watch(values['refresh'], values['port'], self, id, values['name'])
+ 
+           
         try:
             self.watch_db[id].updated = values['updated']
         except:
@@ -319,6 +347,9 @@ class Specto:
         elif int(values['type']) == 3: #process
             new_values['process'] = values['process']
 
+        elif int(values['type']) == 4: #port
+            new_values['port'] = values['port']
+
         id = self.create_watch(new_values)
         self.start_watch(id)
 
@@ -350,6 +381,9 @@ class Specto:
         elif int(values['type']) == 3: #process
             new_values['process'] = values['process']
 
+        elif int(values['type']) == 4: #port
+            new_values['port'] = values['port']
+
         self.watch_io.write_options(new_values)
         self.notifier.show_watch_info()
 
@@ -363,7 +397,18 @@ class Specto:
         self.count_updated_watches()
         self.watch_io.remove_watch(name)#do not clear the watch after removing it or it will mess up the watches.list
         self.notifier.model.remove(self.notifier.iter[id])
-        
+    
+    def find_watch(self, name):
+        """
+        Returns the key of a watch or None if it doesn't exists.
+        """
+        k = -1
+        for key in self.watch_db.iterkeys():
+            if self.watch_db[key].name == name: 
+                k = key
+                break
+        return k
+    
     def check_unique_watch(self, name):
         """ Check if the watch name is unique. """
         if self.watch_io.search_watch(name) and GTK:
@@ -373,12 +418,12 @@ class Specto:
         
     def count_updated_watches(self):
         """ Count the number of updated watches for the tooltip. """
-        tooltip_updated_watches = { 0:0,1:0,2:0,3:0 }
+        tooltip_updated_watches = { 0:0,1:0,2:0,3:0,4:0 }#don't forget to update this if you are implementing a new type of watch
         for i in self.watch_db:
             if self.watch_db[i].updated == True:
                 self.tray.set_icon_state_excited()#change the tray icon color to orange
                 tooltip_updated_watches[self.watch_db[i].type] = tooltip_updated_watches[self.watch_db[i].type] + 1
-        if tooltip_updated_watches.values() == [0,0,0,0]:#there are no more watches to clear, reset the tray icon
+        if tooltip_updated_watches.values() == [0,0,0,0,0]:#there are no more watches to clear, reset the tray icon
             self.tray.set_icon_state_normal()
             self.notifier.wTree.get_widget("button_clear_all").set_sensitive(False)
 
@@ -470,16 +515,16 @@ class Specto:
         elif self.notifier_initialized:
             if self.notifier.get_state()==True and self.notifier_keep_hidden:
                 self.logger.log(_("notifier: reappear"), "debug", self.__class__)
-                self.conf_ui.set_entry("/notifier_state", True, "boolean")
+                self.specto_gconf.set_entry("show_notifier", True)
                 self.notifier.restore_size_and_position()#to make sure that the x and y positions don't jump around
                 self.notifier.notifier.show()
             elif self.notifier.get_state()==True and not self.notifier_keep_hidden:
                 self.logger.log(_("notifier: hide"), "debug", self.__class__)
-                self.conf_ui.set_entry("/notifier_state", False, "boolean")
+                self.specto_gconf.set_entry("show_notifier", False)
                 self.notifier.notifier.hide()
             else:
                 self.logger.log(_("notifier: reappear"), "debug", self.__class__)
-                self.conf_ui.set_entry("/notifier_state", True, "boolean")
+                self.specto_gconf.set_entry("show_notifier", True)
                 self.notifier.restore_size_and_position()#to make sure that the x and y positions don't jump around
                 self.notifier.notifier.show()
         self.notifier_initialized = True
@@ -545,7 +590,7 @@ class Specto:
             
     def show_help(self, *args):
         """ Show the help web page. """
-        self.util.show_webpage("http://specto.ecchi.ca")
+        self.util.show_webpage("http://code.google.com/p/specto/w/list")
         
     def import_export_watches(self, action):
         """ Show the import/export window. """
@@ -563,19 +608,36 @@ class Specto:
         try:
             gtk.main_quit()
         except:
-            self.notifier.stop_refresh = True
             #create a close dialog
-            dialog = gtk.Dialog("Error quitting specto", None, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, None)
+            dialog = gtk.Dialog(_("Cannot quit yet"), None, gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR | gtk.DIALOG_DESTROY_WITH_PARENT, None)
+            #HIG tricks
+            dialog.set_has_separator(False)
+            
+            dialog.add_button(_("Murder!"), 3)
             dialog.add_button(gtk.STOCK_CANCEL, -1)
-            dialog.add_button(_("Murder!"), 3)            
-            label = gtk.Label(_('Specto is currently busy and cannot quit yet.\n\nThis may be because it is checking for watch updates.\nHowever, you can try forcing it to quit by clicking the murder button.'))
-            dialog.vbox.pack_start(label, True, True, 20)
+
+            dialog.label_hbox = gtk.HBox(spacing=6)
+            
+            
+            icon = gtk.Image()
+            icon.set_from_pixbuf(self.icon_theme.load_icon("dialog-warning", 64, 0))
+            dialog.label_hbox.pack_start(icon, True, True, 6)
+            icon.show()
+
+            label = gtk.Label(_('<b><big>Specto is currently busy and cannot quit yet.</big></b>\n\nThis may be because it is checking for watch updates.\nHowever, you can try forcing it to quit by clicking the murder button.'))
+            label.set_use_markup(True)
+            dialog.label_hbox.pack_start(label, True, True, 6)#here, pack means "cram the label right at the start of the vbox before the buttons"
             label.show()
-            icon = gtk.gdk.pixbuf_new_from_file(self.PATH + 'icons/specto_window_icon.png' )
+            
+            dialog.vbox.pack_start(dialog.label_hbox, True, True, 12)
+            dialog.label_hbox.show()
+            
+            icon = gtk.gdk.pixbuf_new_from_file(self.PATH + 'icons/specto_window_icon.svg' )
             dialog.set_icon(icon)
             answer = dialog.run()
             if answer == 3:
-                try:
+                try:#go figure, it never works!
+                    self.notifier.stop_refresh = True
                     sys.exit(0)
                 except:
                     #kill the specto process with killall
